QueueWorker class

Ensures queue processing runs on a single sequential worker.

Constructors

QueueWorker()

Properties

hashCode int
The hash code for this object.
no setterinherited
isRunning bool
Whether the worker is currently processing tasks.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start(Future<void> callback()) Future<void>
Starts the worker if it is not already running.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited