DatabaseService class

Opens and prepares the SQLite database used by flow queues.

Constructors

DatabaseService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

init(String tableName) Future<Database>
Opens the database and ensures tableName exists.
normalizeTableName(String tableName) String
Returns a validated SQLite table identifier for tableName.