QueueTask class

A persisted queue task record.

Constructors

QueueTask({required String processId, required String? parentProcessId, required String processName, required QueueState state, required int retryCount, required QueuePriority priority, required int createdAt})
Creates a queue task model.
const
QueueTask.fromMap(Map<String, Object?> map)
Creates a QueueTask from a SQLite row.
factory

Properties

createdAt int
Creation timestamp in milliseconds since epoch.
final
hashCode int
The hash code for this object.
no setterinherited
parentProcessId String?
The task id that created this task via retry, if any.
final
priority QueuePriority
Task priority.
final
processId String
Unique identifier for this task.
final
processName String
Developer-provided task name.
final
retryCount int
Number of retry generations before this task.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state QueueState
Current task state.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this task to a SQLite row map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited