FlowQueue class
Lightweight persistent SQLite-backed queue engine.
Properties
Methods
-
add(
{required String processName, required QueuePriority priority, required Future< void> function()}) → Future<String> - Adds a task to the queue and starts processing pending work.
-
getState(
String processId) → Future< QueueState> -
Returns the current state for
processId. -
getTask(
String processId) → Future< QueueTask> -
Returns the persisted task for
processId. -
init(
) → Future< void> - Opens the SQLite database and prepares this queue table.
-
listen(
String processId) → Stream< QueueTask> -
Streams state updates for
processId. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
retry(
String processId) → Future< String> - Creates a new pending task from an existing task.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited