QueueState enum
The lifecycle state of a queued task.
Values
- pending → const QueueState
-
The task is waiting to be executed.
- inProgress → const QueueState
-
The task is currently being executed by the queue worker.
- success → const QueueState
-
The task completed successfully.
- failed → const QueueState
-
The task failed while executing.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
QueueState> - A constant List of the values in this enum, in order of their declaration.